MessagePackSizeException class
Thrown when a string, collection, or binary blob exceeds MessagePack limits.
MessagePack specifies a maximum size of 2^32 - 1 (approx 4GB) for elements.
- Inheritance
-
- Object
- MessagePackException
- MessagePackSizeException
Constructors
- MessagePackSizeException(String message, [String? suggestion])
-
Creates a MessagePackSizeException.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The description of what went wrong.
finalinherited
- name → String
-
The name of the exception, used in toString.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestion → String?
-
An optional actionable suggestion on how to fix the error.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited