MessagePackUnsupportedTypeException class

Thrown when attempting to serialize an object that isn't supported.

This happens when an object is not a primitive type, not a collection, and has no registered custom extension encoder.

Inheritance

Constructors

MessagePackUnsupportedTypeException(Type unsupportedType, String message, [String? suggestion])
Creates a MessagePackUnsupportedTypeException.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The description of what went wrong.
finalinherited
name String
The name of the exception, used in toString.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestion String?
An optional actionable suggestion on how to fix the error.
finalinherited
unsupportedType Type
The runtime type of the object that caused the serialization failure.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited