MessagePackConfigurationException class
Thrown when there's an error in the custom extension configuration.
Examples include registering duplicate extension IDs, using out-of-range IDs (-128 to 127), or missing decoders.
- Inheritance
-
- Object
- MessagePackException
- MessagePackConfigurationException
Constructors
- MessagePackConfigurationException(String message, [String? suggestion])
-
Creates a MessagePackConfigurationException.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The description of what went wrong.
finalinherited
- name → String
-
The name of the exception, used in toString.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestion → String?
-
An optional actionable suggestion on how to fix the error.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited