MessagePackFormatException class
Thrown when the binary data does not conform to the MessagePack specification.
Examples include encountering reserved bytes (0xc1), malformed timestamps, or calling unpack on an empty buffer.
- Inheritance
-
- Object
- MessagePackException
- MessagePackFormatException
Constructors
- MessagePackFormatException(String message, [String? suggestion])
-
Creates a MessagePackFormatException.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The description of what went wrong.
finalinherited
- name → String
-
The name of the exception, used in toString.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestion → String?
-
An optional actionable suggestion on how to fix the error.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited