MessagePackGroup class
Builder for grouping multiple types under a single extension ID.
Instances are created internally by MessagePack.registerGroup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add<
T> ({required int subId, required Encoder< T> encoder, required Decoder<T> decoder, bool polymorphic = false}) → void -
Adds type
Tto this group with the givensubId. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited