MessagePackStreamTransformer class
A StreamTransformer that decodes a stream of MessagePack bytes into a stream of Dart objects.
It uses a zero-allocation MessagePackScanner to validate the exact length
of incoming messages before passing them to the optimized MessagePack
unpacker. This avoids garbage collection overhead from partially decoded
messages when chunk boundaries split large objects.
- Inheritance
-
- Object
- StreamTransformerBase<
List< int> , dynamic> - MessagePackStreamTransformer
Constructors
- MessagePackStreamTransformer(MessagePack _mp)
-
Creates a new MessagePackStreamTransformer using the provided codec.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(
Stream< List< stream) → Streamint> > -
Transforms the provided
stream.override -
cast<
RS, RT> () → StreamTransformer< RS, RT> -
Provides a
StreamTransformer<RS, RT>view of this stream transformer.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited